@@ -66,7 +66,7 @@ xfce4_session_settings_show_saved_sessions (GtkBuilder *builder,
         return;
 
     settings_list_sessions_treeview_init (GTK_TREE_VIEW (sessions_treeview));
-    sessions = settings_list_sessions (rc);
+    sessions = settings_list_sessions (rc, gtk_widget_get_scale_factor (sessions_treeview));
     model = gtk_tree_view_get_model (GTK_TREE_VIEW (sessions_treeview));
     settings_list_sessions_populate (model, sessions);
 }
@@ -85,7 +85,6 @@ main(int argc,
     GError *error = NULL;
     XfconfChannel *channel;
     XfceRc *rc;
-    gboolean visible;
     gchar *active_session;
     gchar *active_session_label;
     const gchar *format;
@@ -119,7 +118,7 @@ main(int argc,
 
     if(G_UNLIKELY(opt_version)) {
         g_print("%s %s (Xfce %s)\n\n", G_LOG_DOMAIN, PACKAGE_VERSION, xfce_version_string ());
-        g_print("%s\n", "Copyright (c) 2004-2022");
+        g_print("%s\n", "Copyright (c) 2004-2023");
         g_print("\t%s\n\n", _("The Xfce development team. All rights reserved."));
         g_print(_("Please report bugs to <%s>."), PACKAGE_BUGREPORT);
         g_print("\n");
@@ -175,6 +174,7 @@ main(int argc,
     markup = g_markup_printf_escaped (format, active_session_label, active_session);
     gtk_label_set_markup (GTK_LABEL (label_active_session), markup);
     g_free (markup);
+    g_free (active_session);
 
     delete_button = gtk_builder_get_object (builder, "btn_delete_session");
     treeview = gtk_builder_get_object (builder, "saved-sessions-list");
@@ -182,11 +182,9 @@ main(int argc,
 
     /* Check if there are saved sessions and if so, show the "Saved Sessions" tab */
     rc = settings_list_sessions_open_rc ();
-    if (rc)
-        visible = TRUE;
-    else
-        visible = FALSE;
-    xfce4_session_settings_show_saved_sessions (builder, rc, visible);
+    xfce4_session_settings_show_saved_sessions (builder, rc, rc != NULL);
+    if (rc != NULL)
+        xfce_rc_close (rc);
 
     /* bind widgets to xfconf */
     xfconf_g_property_bind(channel, "/chooser/AlwaysDisplay", G_TYPE_BOOLEAN,
