@@ -164,7 +164,7 @@ session_editor_save_session(GtkWidget *btn,
     if (rc)
     {
         gtk_widget_show (gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), 3));
-        sessions = settings_list_sessions (rc);
+        sessions = settings_list_sessions (rc, gtk_widget_get_scale_factor (treeview));
         model = gtk_tree_view_get_model (GTK_TREE_VIEW (treeview));
         /* If the treeview hasn't been initialized we do it now */
         if (!GTK_IS_LIST_STORE (model))
@@ -359,6 +359,8 @@ session_editor_set_from_desktop_file(GtkTreeModel *model,
                        COL_ICON_NAME, gicon,
                        COL_HAS_DESKTOP_FILE, TRUE,
                        -1);
+    if (gicon != NULL)
+        g_object_unref (gicon);
 
     xfce_rc_close(rcfile);
 }
@@ -532,6 +534,7 @@ manager_client_registered(XfsmManager *proxy,
             g_free (property);
             g_variant_unref (variant_value);
     }
+    g_variant_iter_free (variant_iter);
 
     if(!name || !*name)
         name = _("(Unknown program)");
@@ -559,6 +562,8 @@ manager_client_registered(XfsmManager *proxy,
         gtk_list_store_set (GTK_LIST_STORE (model), &iter,
                             COL_ICON_NAME, gicon,
                             -1);
+        if (gicon != NULL)
+            g_object_unref (gicon);
     }
 
     path = gtk_tree_model_get_path(model, &iter);
